Learn R Programming

geoprofiler (version 0.0.3)

vrotate: Vector rotation

Description

Vector rotation about a given axis and angle after Schaeben et al. (2024)

Usage

vrotate(x, rotaxis, rotangle)

Value

numeric 3-column matrix

Arguments

x, rotaxis

numeric 3-column matrices representing vectors

rotangle

numeric. Angle in radians

References

Schaeben, H., Kroner, U., Stephan, T., 2024. "Mathematical fundamentals of spherical kinematics of plate tectonics in terms of quaternions". Math. Methods Appl. Sci. 47, 4469–4496. tools:::Rd_expr_doi("10.1002/mma.9823")