powered by
Vector rotation about a given axis and angle after Schaeben et al. (2024)
vrotate(x, rotaxis, rotangle)
numeric 3-column matrix
numeric 3-column matrices representing vectors
numeric. Angle in radians
Schaeben, H., Kroner, U., Stephan, T., 2024. "Mathematical fundamentals of spherical kinematics of plate tectonics in terms of quaternions". Math. Methods Appl. Sci. 47, 4469–4496. tools:::Rd_expr_doi("10.1002/mma.9823")